==> lmtpd-0.9.19.tar.gz: lmtpd-0.9.19/debug.c <==
/*
   Copyright 2000, 2001, 2002, 2003 Laurent Wacrenier

   This file is part of PLL lmtpd.

   PLL lmtpd is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2 of the License, or
   (at your option) any later version.

   PLL lmtpd is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with PLL lmtpd; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

*/

static char const rcsid[] =
"$Id: debug.c,v 1.1 2003/11/07 17:13:39 lwa Exp $";

#include "config.h"

#include <stdio.h>

#include "lmtp.h"

int debug_close(struct fstate *state, FILE *f) {
  char *path = acl_mailbox(&(state->filter_debug_msg), state->rcpt->mbox);
  char domain[255];
  char tmpname[PATH_MAX];
  FILE *msg, *tmp;
  int c;

  if (path == NULL) {
      return -1;
  }

  getuserdomain(state->qrecipient, domain);
  if ((msg = opentemplate(path, domain))==NULL)
    return -1;
  if ((tmp=newmessage(state, "debug", tmpname))==NULL) {
      fclose(msg);
      return -1;
  }

  while((c=fgetc(msg))!=EOF) {
    if (c=='%') {
      c=fgetc(msg);
      switch(c) {
      case 'D':
	fputs(domain, tmp);
	break;
      case 'R':
	fputs(state->qrecipient, tmp);
	break;
      case 's': {
        char stamp[100];
        strftime(stamp, sizeof(stamp)-1,
                 "%Y%m%d%H%M%S", localtime(&(state->date)));
        fputs(stamp, tmp);
	break;
      }
      case 'X': {
	char buf[8192];
	size_t read_len;
	rewind(state->filter_debug);
	while((read_len = fread(buf, 1, sizeof(buf), f)) > 0) {
	  fwrite(buf, 1, read_len, tmp);
	}
	break;
      }
      case 'H': {
	ssize_t bodysize = state->bodysize;
	fflush(tmp);
	state->bodysize = 0;
	mailwrite(state, state->hdrlist, HEADER_OTHER,
		  fileno(tmp));
	state->bodysize = bodysize;
	break;
      }
      case 'B':
	fflush(tmp);
	write(fileno(tmp), state->body, state->bodysize);
	break;
      case EOF:
	break;
      default:
	fputc(c, tmp);
      }
    } else {
      fputc(c, tmp);
    }
  }
  fclose(msg);
  if (endmessage(state, "debug", tmpname, tmp) == EOF) {
    return -1;
  }
  return 0;
}

FILE *debug_init(struct fstate *state) {
  char tmpname[PATH_MAX];
  int fd = opentmp(state, tmpname);
  FILE *f;
  if (fd == -1)
    return NULL;
  unlink(tmpname);
  if ((f = fdopen(fd, "r+")) != NULL) {
    return f;
  } else {
    close(fd);
    return NULL;
  }
}

==> lmtpd-0.10.4.tar.gz: lmtpd-0.10.4/debug.c <==
/*
   Copyright 2000, 2001, 2002, 2003 Laurent Wacrenier

   This file is part of PLL lmtpd.

   PLL lmtpd is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2 of the License, or
   (at your option) any later version.

   PLL lmtpd is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with PLL lmtpd; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

*/

#include "config.h"

static char const rcsid[] UNUSED =
"$Id: debug.c,v 1.2 2004/10/26 09:59:20 lwa Exp $";



#include <stdio.h>

#include "lmtp.h"

int debug_close(struct fstate *state, FILE *f) {
  char *path = acl_mailbox(&(state->filter_debug_msg), state->rcpt->mbox);
  char domain[255];
  char tmpname[PATH_MAX];
  FILE *msg, *tmp;
  int c;

  if (path == NULL) {
      return -1;
  }

  getuserdomain(state->qrecipient, domain);
  if ((msg = opentemplate(path, domain))==NULL)
    return -1;
  if ((tmp=newmessage(state, "debug", tmpname))==NULL) {
      fclose(msg);
      return -1;
  }

  while((c=fgetc(msg))!=EOF) {
    if (c=='%') {
      c=fgetc(msg);
      switch(c) {
      case 'D':
	fputs(domain, tmp);
	break;
      case 'R':
	fputs(state->qrecipient, tmp);
	break;
      case 's': {
        char stamp[100];
        strftime(stamp, sizeof(stamp)-1,
                 "%Y%m%d%H%M%S", localtime(&(state->date)));
        fputs(stamp, tmp);
	break;
      }
      case 'X': {
	char buf[8192];
	size_t read_len;
	rewind(state->filter_debug);
	while((read_len = fread(buf, 1, sizeof(buf), f)) > 0) {
	  fwrite(buf, 1, read_len, tmp);
	}
	break;
      }
      case 'H': {
	ssize_t bodysize = state->bodysize;
	fflush(tmp);
	state->bodysize = 0;
	mailwrite(state, state->hdrlist, HEADER_OTHER,
		  fileno(tmp));
	state->bodysize = bodysize;
	break;
      }
      case 'B':
	fflush(tmp);
	write(fileno(tmp), state->body, state->bodysize);
	break;
      case EOF:
	break;
      default:
	fputc(c, tmp);
      }
    } else {
      fputc(c, tmp);
    }
  }
  fclose(msg);
  if (endmessage(state, "debug", tmpname, tmp) == EOF) {
    return -1;
  }
  return 0;
}

FILE *debug_init(struct fstate *state) {
  char tmpname[PATH_MAX];
  int fd = opentmp(state, tmpname);
  FILE *f;
  if (fd == -1)
    return NULL;
  unlink(tmpname);
  if ((f = fdopen(fd, "r+")) != NULL) {
    return f;
  } else {
    close(fd);
    return NULL;
  }
}
